@@ -322,6 +322,12 @@ impl Form {
             .collect()
     }
 
+    pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)> {
+        self.parameter_map
+            .iter()
+            .map(|(key, parameter)| (key.as_str(), &parameter.value))
+    }
+
     /**
      * Returns the number of items.
      */
@@ -407,11 +413,11 @@ impl Form {
     }
 }
 
-impl<'a> IntoIterator for &'a Form {
-    type Item = <&'a HashMap<String, Parameter> as IntoIterator>::Item;
-    type IntoIter = <&'a HashMap<String, Parameter> as IntoIterator>::IntoIter;
+impl IntoIterator for Form {
+    type Item = <HashMap<String, Parameter> as IntoIterator>::Item;
+    type IntoIter = <HashMap<String, Parameter> as IntoIterator>::IntoIter;
     fn into_iter(self) -> Self::IntoIter {
-        self.parameter_map.iter()
+        self.parameter_map.into_iter()
     }
 }
 
